Developer Guide
===============

Programming HowTos and Tutorials
--------------------------------
.. toctree::
    :maxdepth: 3

    development.guidelines
    development.environment
    unit_tests
    how_to_participate


Background Concepts for Savanna
-------------------------------
.. toctree::
    :maxdepth: 3

    plugins
    templates


Other Resources
---------------
.. toctree::
   :maxdepth: 3

   launchpad
   gerrit
   jenkins